compute_density_values: Convenience function for computing density values for...

View source: R/pow_sim.r

compute_density_valuesR Documentation

Convenience function for computing density values for plotting.

Description

Convenience function for computing density values for plotting.

Usage

compute_density_values(data, group_var, parameter, values, term_col = "term")

Arguments

data

A dataframe that contains the parameter estimates.

group_var

A group variable that specifies the attributes to group by. By default, this would likely be the term attribute, but can contain more than one attribute.

parameter

The attribute that represents the parameter estimate.

values

A list of numeric vectors that specifies the values for which the density values are computed for.

term_col

A character vector representing the term column in the data, this should almost always be "term" unless renamed.


simglm documentation built on Sept. 2, 2026, 1:07 a.m.