parse_varyarguments_w: Parse within varying arguments

View source: R/parse_formula.r

parse_varyarguments_wR Documentation

Parse within varying arguments

Description

Parse within varying arguments

Usage

parse_varyarguments_w(sim_args, name)

Arguments

sim_args

A named list with special model formula syntax. See details and examples for more information. The named list may contain the following:

  • fixed: This is the fixed portion of the model (i.e. covariates)

  • random: This is the random portion of the model (i.e. random effects)

  • error: This is the error (i.e. residual term).

name

The name of the within simulation condition. This is primarily an internal function.


simglm documentation built on Sept. 2, 2026, 1:07 a.m.