simulate_propensity: Simulate Propensity Scores

View source: R/propensity.r

simulate_propensityR Documentation

Simulate Propensity Scores

Description

Process to simulate propensity scores.

Usage

simulate_propensity(sim_args)

Arguments

sim_args

A named list with special model formula syntax. See details and examples for more information. The named list may contain the following:

  • fixed: This is the fixed portion of the model (i.e. covariates)

  • random: This is the random portion of the model (i.e. random effects)

  • error: This is the error (i.e. residual term).


simglm documentation built on Sept. 2, 2026, 1:07 a.m.